#
# spec file for package dcmtk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define abiversion 17
Name:           dcmtk
Version:        3.6.7
Release:        3.1
Summary:        DICOM Toolkit
License:        Apache-2.0 AND BSD-3-Clause
Group:          Productivity/Scientific/Other
URL:            https://dicom.offis.de/dcmtk.php.en
Source0:        ftp://dicom.offis.de/pub/dicom/offis/software/dcmtk/release/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE dcmtk-fix-DCMTKTargets.cmake.patch -- Do not track executables to be able to use dcmtk-devel without dcmtk package
Patch0:         dcmtk-fix-DCMTKTargets.cmake.patch
# PATCH-FIX-UPSTREAM -- CVE-2022-43272
Patch1:         dcmtk-CVE-2022-43272.patch
# https://git.dcmtk.org/?p=dcmtk.git;a=commit;h=331c4d9011a19623aee3d82f2c4d35e903528e03
# PATCH-FIX-UPSTREAM dcmtk-fix-pkgconfig.patch -- Removed leading spaces in dcmtk.pc.in.
Patch2:         dcmtk-fix-pkgconfig.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtiff-devel
# Workaround for boo#1201799
BuildRequires:  openjpeg2
BuildRequires:  pkgconfig
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(zlib)

%description
DCMTK is a collection of libraries and applications implementing large
parts the DICOM standard.

%package devel
Summary:        Development files for dcmtk
Group:          Development/Libraries/C and C++
Requires:       libdcmtk%{abiversion} = %{version}
Requires:       tcpd-devel

%description devel
This package provides development libraries and headers needed to build
software using dcmtk.

%package -n libdcmtk%{abiversion}
Summary:        DICOM Toolkit
Group:          System/Libraries
Provides:       libdcmtk3_6 = %{version}
Obsoletes:      libdcmtk3_6 < %{version}

%description -n libdcmtk%{abiversion}
DCMTK is a collection of libraries and applications implementing large
parts the DICOM standard.

%prep
%autosetup -p1

%build
%cmake \
 -DBUILD_SHARED_LIBS=ON \
 -DDCMTK_WITH_XML=ON \
 -DDCMTK_WITH_OPENSSL=ON \
 -DDCMTK_WITH_SNDFILE=ON \
 -DDCMTK_WITH_ZLIB=ON

%cmake_build

%install
%cmake_install

# Remove zero-length file (fix rpmlint warning)
rm %{buildroot}%{_datadir}/dcmtk/wlistdb/OFFIS/lockfile

# Move configuration files from /usr/etc to /etc/
mv %{buildroot}%{_prefix}%{_sysconfdir} %{buildroot}

# Move doc files from /usr/share/doc/dcmtk to /usr/share/doc/packages/dcmtk/
mkdir %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}

# Install README file to documentation
install -pm 0644 README %{buildroot}%{_docdir}/dcmtk/

%fdupes -s %{buildroot}

%post -n libdcmtk%{abiversion} -p /sbin/ldconfig
%postun -n libdcmtk%{abiversion} -p /sbin/ldconfig

%files
%license COPYRIGHT
%doc CREDITS FAQ README
%doc %{_docdir}/dcmtk/
%config(noreplace) %{_sysconfdir}/dcmtk/*.cfg
%dir %{_sysconfdir}/dcmtk
%{_bindir}/*
%{_datadir}/dcmtk/
%{_mandir}/man1/*

%files devel
%license COPYRIGHT
%{_includedir}/dcmtk/
%{_libdir}/*.so
%{_libdir}/cmake/dcmtk/
%{_libdir}/pkgconfig/dcmtk.pc

%files -n libdcmtk%{abiversion}
%license COPYRIGHT
%{_libdir}/*.so.%{abiversion}
%{_libdir}/*.so.%{abiversion}.3.6*

%changelog
* Thu Dec 14 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add dcmtk-fix-pkgconfig.patch: Removed leading spaces in
  dcmtk.pc.in. This in turn makes the .pc file actually valid.
* Thu May 11 2023 Christophe Marin <christophe@krop.fr>
- Add upstream change (boo#1206070, CVE-2022-43272):
  * dcmtk-CVE-2022-43272.patch
* Sat Jul 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.6.7 (boo#1208639, boo#1208638, boo#1208637,
  CVE-2022-2121, CVE-2022-2120, CVE-2022-2119)
  See DOCS/CHANGES.367 for the full list of changes
  * Updated code definitions for DICOM 2022b
  * Fixed possible NULL pointer dereference
- Rebase dcmtk-fix-DCMTKTargets.cmake.patch
* Mon Apr 25 2022 Christophe Giboudeaux <christophe@krop.fr>
- Fix the package soname
* Tue Apr 20 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.6.6. See DOCS/CHANGES.366 for more information
- Drop 0001-Link-charls-statically.patch
- Spec cleanup
* Thu Oct 22 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to avoid file conflict between dcmtk and charls:
  * 0001-Link-charls-statically.patch
* Fri Apr  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Explicitly require tcpd-devel. The dcmnet library links to libwrap.
* Wed Nov 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.6.5. See DOCS/CHANGES.365 for more information
  * Updated code definitions for DICOM 2018e
  * Fix some -Wunused-result warnings warnings
  * Fixed CMake error if "FindPkgConfig" is missing
* Tue Mar 19 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix a typo detected by Leap 15.1
- Update to 3.6.4. See DOCS/CHANGES.364 for more information
- Rebase dcmtk-fix-DCMTKTargets.cmake.patch
- Drop dcmtk-fix-CONFIGURE_PACKAGE_CONFIG_FILE.patch, merged upstream
* Tue Jul 10 2018 guillaume.gardet@opensuse.org
- Add patch to fix path in DCMTKConfig.cmake:
  * dcmtk-fix-CONFIGURE_PACKAGE_CONFIG_FILE.patch
* Fri May 25 2018 christophe@krop.fr
- Update to 3.6.3. See DOCS/CHANGES.363 for more information
  * Fix some buildsystem issues
  * Enabled new TLS versions when using OpenSSL < 1.1.0
- Drop dcmtk-3.6.0-0002-Install-libs-in-the-correct-arch-dir.patch.
* Sat Nov 18 2017 christophe@krop.fr
- Fix dcmtk-fix-DCMTKTargets.cmake.patch
* Fri Nov 17 2017 guillaume@opensuse.org
- Add dcmtk-fix-DCMTKTargets.cmake.patch to fix usage of 'dcmtk-devel'
  without 'dcmtk' package
* Tue Jul 25 2017 tittiatcoke@gmail.com
- Update to version 3.6.2
  * See DOCS/CHANGES.362 for more information
- Build against the internal CharLS library. Only version 1.0 is
  supported and Factory offers version 2.0
  * Drop patches:
  - dcmtk-3.6.0-0004-Use-system-charls.patch
  - dcmtk-3.6.0-0003-Removed-bundled-libcharl-reference-in-dcmjpls.patch
  - dcmtk-3.6.0-0005-Fixed-includes-for-CharLS-1.0.patch
- Drop patches due to updated build system and upstream integration:
  * dcmtk-3.6.0-0001-Added-soname-information-for-all-targets.patch
  * dcmtk-3.6.0-0006-Added-optional-support-for-building-shared-libraries.patch
  * dcmtk-3.6.0-0007-Add-soname-generation-for-modules-which-are-not-in-D.patch
  * dcmtk-3.6.0.diff
  * gcc-4.7_fix.patch
* Thu Aug 30 2012 pgajdos@suse.com
- require libpng-devel instead of libpng14-compat-devel;
  libpng14-compat-devel is now default libpng-devel provider for
  factory; moreover dcmtk builds correctly with libpng15-devel too
* Sun Mar 18 2012 asterios.dramis@gmail.com
- Added a patch (gcc-4.7_fix.patch) to fix compilation with gcc-4.7.
- Remove zero-length file /usr/share/dcmtk/wlistdb/OFFIS/lockfile (fix rpmlint
  warning).
* Tue Dec 13 2011 coolo@suse.com
- fix last change
* Mon Dec 12 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changed libdcmtk3 subpackage name to libdcmtk3_6 which is the correct one
    according to openSUSE shared library packaging policy.
* Sun Dec 11 2011 asterios.dramis@gmail.com
- Added seven patches (taken from Fedora) to make the package build shared
  libraries (using cmake) and link to the system "CharLS" library instead of
  the internal copy:
  + dcmtk-3.6.0-0001-Added-soname-information-for-all-targets.patch
  + dcmtk-3.6.0-0002-Install-libs-in-the-correct-arch-dir.patch
  + dcmtk-3.6.0-0003-Removed-bundled-libcharl-reference-in-dcmjpls.patch
  + dcmtk-3.6.0-0004-Use-system-charls.patch
  + dcmtk-3.6.0-0005-Fixed-includes-for-CharLS-1.0.patch
  + dcmtk-3.6.0-0006-Added-optional-support-for-building-shared-libraries.patch
  + dcmtk-3.6.0-0007-Add-soname-generation-for-modules-which-are-not-in-D.patch
- Added a patch "dcmtk-3.6.0.diff" to fix libraries linking.
- Spec file updates:
  * Changed License: entry to SPDX style. Removed "AS IS" to fix rpmlint
    warning "invalid-license".
  * Adapted spec file to the cmake usage and building of shared libraries.
    Added a libdcmtk3 subpackage.
  * Added CharLS-devel in BuildRequires:.
* Thu Sep 22 2011 toddrme2178@gmail.com
- Added build of development files.  Without these other software
  can't make use of this.
* Mon Aug 29 2011 toddrme2178@gmail.com
- Added ASL-2.0 to the spec file license tag (see bnc #711187)
* Thu Aug  4 2011 toddrme2178@gmail.com
- Created proper spec file with macors and a real %%files section
- Moved changes to a .changes file
- Removed tests for other distributions
- Switched Url to the source of the tarball rather than the source
  of the original rpm
* Sat Aug 23 2008 stkaopen@gmx.at
- packaged dcmtk version 3.5.4 using the buildservice spec file wizard
